@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2012-2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2012-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -41,13 +41,13 @@ command::command (octave_pq_connection_rep &connection, std::string &cmd,
   if (! (cptr = conn.octave_pq_get_conn ()))
     {
       valid = 0;
-      c_verror ("%s: connection not open", caller.c_str ());
+      _p_error ("%s: connection not open", caller.c_str ());
     }
 
   if (! PQsendQuery (cptr, cmd.c_str ()))
     {
       valid = 0;
-      c_verror ("%s: could not dispatch command: %s", caller.c_str (),
+      _p_error ("%s: could not dispatch command: %s", caller.c_str (),
                 PQerrorMessage (cptr));
     }
   else
@@ -65,7 +65,7 @@ command::command (octave_pq_connection_rep &connection, std::string &cmd,
   if (! (cptr = conn.octave_pq_get_conn ()))
     {
       valid = 0;
-      c_verror ("%s: connection not open", caller.c_str ());
+      _p_error ("%s: connection not open", caller.c_str ());
     }
 
   int npars = params.numel ();
@@ -92,7 +92,7 @@ command::command (octave_pq_connection_rep &connection, std::string &cmd,
           pq_oct_type_t oct_type;
           oct_pq_conv_t *conv;
 
-          if (ptypes(i).is_empty ())
+          if (ptypes(i).OV_ISEMPTY ())
             {
               oct_type = simple;
 
@@ -113,7 +113,7 @@ command::command (octave_pq_connection_rep &connection, std::string &cmd,
               if (err)
                 {
                   valid = 0;
-                  c_verror ("%s: parameter type specification no string",
+                  _p_error ("%s: parameter type specification no string",
                             caller.c_str ());
                   break;
                 }
@@ -150,7 +150,7 @@ command::command (octave_pq_connection_rep &connection, std::string &cmd,
             default:
               // should not get here
               valid = 0;
-              c_verror ("%s: internal error, undefined type identifier",
+              _p_error ("%s: internal error, undefined type identifier",
                         caller.c_str ());
 
             }
@@ -244,11 +244,11 @@ octave_value command::process_single_result (const std::string &infile,
         {
         case PGRES_BAD_RESPONSE:
           valid = 0;
-          c_verror ("%s: server response not understood", caller.c_str ());
+          _p_error ("%s: server response not understood", caller.c_str ());
           break;
         case PGRES_FATAL_ERROR:
           valid = 0;
-          c_verror ("%s: fatal error: %s", caller.c_str (),
+          _p_error ("%s: fatal error: %s", caller.c_str (),
                     PQresultErrorMessage (res));
           break;
         case PGRES_COMMAND_OK:
@@ -267,7 +267,7 @@ octave_value command::process_single_result (const std::string &infile,
           break;
         default:
           valid = 0;
-          c_verror ("internal error, unexpected server response");
+          _p_error ("internal error, unexpected server response");
         }
 
       if (res) // could have been changed by a handler
@@ -303,9 +303,9 @@ octave_value command::tuples_ok_handler (void)
       if (l != nf)
         {
           valid = 0;
-          c_verror ("%s: wrong number of given returned types",
+          _p_error ("%s: wrong number of given returned types",
                     caller.c_str ());
-          return octave_value_list ();
+          return octave_value ();
         }
       rtypes_given = true;
     }
@@ -334,7 +334,7 @@ octave_value command::tuples_ok_handler (void)
           if (err)
             {
               valid = 0;
-              c_verror ("%s: could not convert given type to string",
+              _p_error ("%s: could not convert given type to string",
                         caller.c_str ());
               break;
             }
@@ -419,7 +419,7 @@ octave_value command::tuples_ok_handler (void)
 
                 default:
                   // should not get here
-                  c_verror ("%s: internal error, undefined type identifier",
+                  _p_error ("%s: internal error, undefined type identifier",
                             caller.c_str ());
 
                   valid = 0;
@@ -437,7 +437,7 @@ octave_value command::tuples_ok_handler (void)
     }
 
   if (! valid)
-    return octave_value_list ();
+    return octave_value ();
   else
     {
       ret.assign ("data", octave_value (data));
@@ -466,7 +466,7 @@ octave_value command::copy_out_handler (const std::string &outfile)
       if (ostr.fail ())
         {
           valid = 0;
-          c_verror ("could not open output file %s", outfile.c_str ());
+          _p_error ("could not open output file %s", outfile.c_str ());
           return retval;
         }
 
@@ -478,7 +478,7 @@ octave_value command::copy_out_handler (const std::string &outfile)
             {
               ostr.write (data, nb);
               if (ostr.bad ())
-                c_verror ("write to file failed");
+                _p_error ("write to file failed");
             }
           PQfreemem (data);
         }
@@ -489,7 +489,7 @@ octave_value command::copy_out_handler (const std::string &outfile)
       if (nb == -2)
         {
           valid = 0;
-          c_verror ("server error in copy-out: %s", PQerrorMessage (cptr));
+          _p_error ("server error in copy-out: %s", PQerrorMessage (cptr));
         }
       else
         {
@@ -500,21 +500,21 @@ octave_value command::copy_out_handler (const std::string &outfile)
               if ((state = PQresultStatus (res)) == PGRES_FATAL_ERROR)
                 {
                   valid = 0;
-                  c_verror ("server error in copy-out: %s",
+                  _p_error ("server error in copy-out: %s",
                             PQerrorMessage (cptr));
                 }
             }
           else
             {
               valid = 0;
-              c_verror ("unexpectedly got no result information");
+              _p_error ("unexpectedly got no result information");
             }
         }
     }
   else
     {
       valid = 0;
-      c_verror ("no output file given");
+      _p_error ("no output file given");
     }
 
   return octave_value (std::string ("copy out"));
@@ -540,7 +540,7 @@ octave_value command::copy_in_handler (const std::string &infile,
         {
           valid = 0;
 
-          c_verror ("no input file given");
+          _p_error ("no input file given");
 
           return retval;
         }
@@ -548,11 +548,11 @@ octave_value command::copy_in_handler (const std::string &infile,
       std::ifstream istr (infile.c_str (), std::ios_base::in);
       if (istr.fail ())
         {
-          c_verror ("could not open input file %s", infile.c_str ());
+          _p_error ("could not open input file %s", infile.c_str ());
 
           PQputCopyEnd (cptr, "could not open input file");
 
-          c_verror ("server error: %s", PQerrorMessage (cptr));
+          _p_error ("server error: %s", PQerrorMessage (cptr));
 
           valid = 0;
 
@@ -567,7 +567,7 @@ octave_value command::copy_in_handler (const std::string &infile,
             {
               valid = 0;
 
-              c_verror ("could not read file %s", infile.c_str ());
+              _p_error ("could not read file %s", infile.c_str ());
 
               break;
             }
@@ -580,7 +580,7 @@ octave_value command::copy_in_handler (const std::string &infile,
                   {
                     valid = 0;
                     
-                    c_verror ("%s", PQerrorMessage (cptr));
+                    _p_error ("%s", PQerrorMessage (cptr));
 
                     break;
                   }
@@ -594,14 +594,14 @@ octave_value command::copy_in_handler (const std::string &infile,
         {
           PQputCopyEnd (cptr, "copy-in interrupted");
 
-          c_verror ("%s", PQerrorMessage (cptr));
+          _p_error ("%s", PQerrorMessage (cptr));
         }
       else
         {
           if (PQputCopyEnd (cptr, NULL) == -1)
             {
               valid = 0;
-              c_verror ("%s", PQerrorMessage (cptr));
+              _p_error ("%s", PQerrorMessage (cptr));
             }
           else
             {
@@ -612,14 +612,14 @@ octave_value command::copy_in_handler (const std::string &infile,
                   if ((state = PQresultStatus (res)) == PGRES_FATAL_ERROR)
                     {
                       valid = 0;
-                      c_verror ("server error in copy-in: %s",
+                      _p_error ("server error in copy-in: %s",
                                 PQerrorMessage (cptr));
                     }
                 }
               else
                 {
                   valid = 0;
-                  c_verror ("unexpectedly got no result information");
+                  _p_error ("unexpectedly got no result information");
                 }
             }
         }
@@ -637,7 +637,7 @@ octave_value command::copy_in_handler (const std::string &infile,
         {
           valid = 0;
 
-          c_verror ("variable for copy-in has %i columns, but should have %i",
+          _p_error ("variable for copy-in has %i columns, but should have %i",
                     c, nf + oids);
 
           PQputCopyEnd
@@ -647,7 +647,7 @@ octave_value command::copy_in_handler (const std::string &infile,
         {
           valid = 0;
 
-          c_verror ("copy-in from variable must use binary mode");
+          _p_error ("copy-in from variable must use binary mode");
 
           PQputCopyEnd (cptr, "copy-in from variable must use binary mode");
         }
@@ -658,7 +658,7 @@ octave_value command::copy_in_handler (const std::string &infile,
               {
                 valid = 0;
 
-                c_verror ("copy-in from variable must use binary mode in all columns");
+                _p_error ("copy-in from variable must use binary mode in all columns");
 
                 PQputCopyEnd (cptr, "copy-in from variable must use binary mode in all columns");
 
@@ -668,7 +668,7 @@ octave_value command::copy_in_handler (const std::string &infile,
 
       if (! valid)
         {
-          c_verror ("server error: %s", PQerrorMessage (cptr));
+          _p_error ("server error: %s", PQerrorMessage (cptr));
 
           return retval;
         }
@@ -689,7 +689,7 @@ octave_value command::copy_in_handler (const std::string &infile,
 
           valid = 0;
 
-          c_verror ("server error: %s", PQerrorMessage (cptr));
+          _p_error ("server error: %s", PQerrorMessage (cptr));
         }
       else
         {
@@ -702,11 +702,11 @@ octave_value command::copy_in_handler (const std::string &infile,
               int16_t fc = htobe16 (int16_t (nf));
               if (PQputCopyData (cptr, (char *) &fc, 2) == -1)
                 {
-                  c_verror ("%s", PQerrorMessage (cptr));
+                  _p_error ("%s", PQerrorMessage (cptr));
 
                   PQputCopyEnd (cptr, "error sending field count");
 
-                  c_verror ("server error: %s", PQerrorMessage (cptr));
+                  _p_error ("server error: %s", PQerrorMessage (cptr));
 
                   valid = 0;
 
@@ -724,7 +724,7 @@ octave_value command::copy_in_handler (const std::string &infile,
                         {
                           valid = 0;
 
-                          c_verror ("could not send NULL in copy-in");
+                          _p_error ("could not send NULL in copy-in");
 
                           break;
                         }
@@ -741,13 +741,13 @@ octave_value command::copy_in_handler (const std::string &infile,
                                 {
                                   valid = 0;
 
-                                  c_verror ("could not get converter for oid in copy-in");
+                                  _p_error ("could not get converter for oid in copy-in");
                                   break;
                                 }
                             }
                           else
                             {
-                              if (cin_types(j).is_empty ())
+                              if (cin_types(j).OV_ISEMPTY ())
                                 {
                                   oct_types[j] = simple;
 
@@ -757,7 +757,7 @@ octave_value command::copy_in_handler (const std::string &infile,
                                     {
                                       valid = 0;
 
-                                      c_verror ("could not determine type in column %i for copy-in",
+                                      _p_error ("could not determine type in column %i for copy-in",
                                                 j);
 
                                       break;
@@ -773,7 +773,7 @@ octave_value command::copy_in_handler (const std::string &infile,
                                     {
                                       valid = 0;
 
-                                      c_verror ("column type specification no string");
+                                      _p_error ("column type specification no string");
 
                                       break;
                                     }
@@ -784,7 +784,7 @@ octave_value command::copy_in_handler (const std::string &infile,
                                     {
                                       valid = 0;
 
-                                      c_verror ("invalid column type specification");
+                                      _p_error ("invalid column type specification");
 
                                       break;
                                     }
@@ -816,7 +816,7 @@ octave_value command::copy_in_handler (const std::string &infile,
 
                         default:
                           // should not get here
-                          c_verror ("internal error, undefined type identifier");
+                          _p_error ("internal error, undefined type identifier");
                           conversion_failed = true;
                         }
 
@@ -832,13 +832,13 @@ octave_value command::copy_in_handler (const std::string &infile,
                           if (PQputCopyData (cptr, (char *) &t, 4) == -1)
                             {
                               valid = 0;
-                              c_verror ("could not send data length in copy-in");
+                              _p_error ("could not send data length in copy-in");
                             }
                           else if (PQputCopyData (cptr, &(val.front ()),
                                                   val.size ()) == -1)
                             {
                               valid = 0;
-                              c_verror ("could not send copy-in data");
+                              _p_error ("could not send copy-in data");
                             }
                         }
 
@@ -850,7 +850,7 @@ octave_value command::copy_in_handler (const std::string &infile,
                 {
                   PQputCopyEnd (cptr, "error sending copy-in data");
 
-                  c_verror ("server error: %s", PQerrorMessage (cptr));
+                  _p_error ("server error: %s", PQerrorMessage (cptr));
 
                   break;
                 }
@@ -864,7 +864,7 @@ octave_value command::copy_in_handler (const std::string &infile,
 
             PQputCopyEnd (cptr, "could not send trailer");
 
-            c_verror ("%s", PQerrorMessage (cptr));
+            _p_error ("%s", PQerrorMessage (cptr));
           }
 
       if (valid)
@@ -872,7 +872,7 @@ octave_value command::copy_in_handler (const std::string &infile,
           if (PQputCopyEnd (cptr, NULL) == -1)
             {
               valid = 0;
-              c_verror ("%s", PQerrorMessage (cptr));
+              _p_error ("%s", PQerrorMessage (cptr));
             }
           else
             {
@@ -883,14 +883,14 @@ octave_value command::copy_in_handler (const std::string &infile,
                   if ((state = PQresultStatus (res)) == PGRES_FATAL_ERROR)
                     {
                       valid = 0;
-                      c_verror ("server error in copy-in: %s",
+                      _p_error ("server error in copy-in: %s",
                                 PQerrorMessage (cptr));
                     }
                 }
               else
                 {
                   valid = 0;
-                  c_verror ("unexpectedly got no result information");
+                  _p_error ("unexpectedly got no result information");
                 }
             }
         }
