@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2012-2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2012-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -88,14 +88,14 @@ private:
       if (! res)
         {
           valid = 0;
-          c_verror ("%s: could not execute command: %s", caller.c_str (),
+          _p_error ("%s: could not execute command: %s", caller.c_str (),
                     PQerrorMessage (cptr));
 
         }
       else if ((state = PQresultStatus (res)) == PGRES_EMPTY_QUERY)
         {
           valid = 0;
-          c_verror ("%s: empty command", caller.c_str ());
+          _p_error ("%s: empty command", caller.c_str ());
         }
     }
 
