@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2012-2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2012-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ int from_octave_str_bool (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to bool value");
+      _p_error ("can not convert octave_value to bool value");
       return 1;
     }
 
@@ -99,7 +99,7 @@ int from_octave_bin_bool (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to bool value");
+      _p_error ("can not convert octave_value to bool value");
       return 1;
     }
 
@@ -154,7 +154,7 @@ int from_octave_bin_oid (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to oid value");
+      _p_error ("can not convert octave_value to oid value");
       return 1;
     }
 
@@ -228,7 +228,7 @@ int from_octave_bin_float8 (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to float8 value");
+      _p_error ("can not convert octave_value to float8 value");
       return 1;
     }
 
@@ -302,7 +302,7 @@ int from_octave_bin_float4 (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to float4 value");
+      _p_error ("can not convert octave_value to float4 value");
       return 1;
     }
 
@@ -361,7 +361,7 @@ int from_octave_bin_bytea (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to bytea representation");
+      _p_error ("can not convert octave_value to bytea representation");
       return 1;
     }
 
@@ -424,7 +424,7 @@ int from_octave_bin_text (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to string");
+      _p_error ("can not convert octave_value to string");
       return 1;
     }
 
@@ -536,7 +536,7 @@ int from_octave_bin_int2 (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to int2 value");
+      _p_error ("can not convert octave_value to int2 value");
       return 1;
     }
 
@@ -592,7 +592,7 @@ int from_octave_bin_int4 (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to int4 value");
+      _p_error ("can not convert octave_value to int4 value");
       return 1;
     }
 
@@ -648,7 +648,7 @@ int from_octave_bin_int8 (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to int8 value");
+      _p_error ("can not convert octave_value to int8 value");
       return 1;
     }
 
@@ -721,9 +721,9 @@ static inline int time_8byte_from_octave (const octave_value &ov,
   if (int_dt)
     {
       // don't convert automatically because of possible overflow
-      if (ov.is_float_type ())
+      if (ov.OV_ISFLOAT ())
         {
-          c_verror ("floating point octave_value provided for 8-byte time value, but postgresql is configured for int64");
+          _p_error ("floating point octave_value provided for 8-byte time value, but postgresql is configured for int64");
           return 1;
         }
 
@@ -733,7 +733,7 @@ static inline int time_8byte_from_octave (const octave_value &ov,
 
       if (err)
         {
-          c_verror ("can not convert octave_value to int64 time value");
+          _p_error ("can not convert octave_value to int64 time value");
           return 1;
         }
 
@@ -744,9 +744,9 @@ static inline int time_8byte_from_octave (const octave_value &ov,
   else
     {
       // don't convert automatically because of possible loss of accuracy
-      if (ov.is_integer_type ())
+      if (ov.OV_ISINTEGER ())
         {
-          c_verror ("integer type octave_value provided for 8-byte time value, but postgresql is configured for double");
+          _p_error ("integer type octave_value provided for 8-byte time value, but postgresql is configured for double");
           return 1;
         }
 
@@ -762,7 +762,7 @@ static inline int time_8byte_from_octave (const octave_value &ov,
 
       if (err)
         {
-          c_verror ("can not convert octave_value to double time value");
+          _p_error ("can not convert octave_value to double time value");
           return 1;
         }
 
@@ -876,7 +876,7 @@ int from_octave_bin_interval (const octave_pq_connection_rep &conn,
   SET_ERR (iv = ov.cell_value (), err);
   if (err || iv.numel () != 3)
     {
-      c_verror ("interval: can not convert octave_value to cell with 3 elements");
+      _p_error ("interval: can not convert octave_value to cell with 3 elements");
       return 1;
     }
 
@@ -891,7 +891,7 @@ int from_octave_bin_interval (const octave_pq_connection_rep &conn,
 
       if (err)
         {
-          c_verror ("interval: can not convert octave_value to int4 value");
+          _p_error ("interval: can not convert octave_value to int4 value");
           return 1;
         }
 
@@ -997,7 +997,7 @@ int from_octave_bin_timetz (const octave_pq_connection_rep &conn,
   SET_ERR (iv = ov.cell_value (), err);
   if (err || iv.numel () != 2)
     {
-      c_verror ("timetz: can not convert octave_value to cell with 2 elements");
+      _p_error ("timetz: can not convert octave_value to cell with 2 elements");
       return 1;
     }
 
@@ -1009,7 +1009,7 @@ int from_octave_bin_timetz (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("timetz: can not convert octave_value to int4 value");
+      _p_error ("timetz: can not convert octave_value to int4 value");
       return 1;
     }
 
@@ -1064,7 +1064,7 @@ int from_octave_bin_date (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("date: can not convert octave_value to int4 value");
+      _p_error ("date: can not convert octave_value to int4 value");
       return 1;
     }
 
@@ -1135,7 +1135,7 @@ int from_octave_bin_point (const octave_pq_connection_rep &conn,
 
   if (err || m.numel () != 2)
     {
-      c_verror ("can not convert octave_value to point representation");
+      _p_error ("can not convert octave_value to point representation");
       return 1;
     }
 
@@ -1218,7 +1218,7 @@ int from_octave_bin_lseg (const octave_pq_connection_rep &conn,
 
   if (err || m.numel () != 4)
     {
-      c_verror ("can not convert octave_value to 4 doubles");
+      _p_error ("can not convert octave_value to 4 doubles");
       return 1;
     }
 
@@ -1335,7 +1335,7 @@ int from_octave_bin_circle (const octave_pq_connection_rep &conn,
 
   if (err || m.numel () != 3)
     {
-      c_verror ("can not convert octave_value to circle representation");
+      _p_error ("can not convert octave_value to circle representation");
       return 1;
     }
 
@@ -1424,7 +1424,7 @@ int from_octave_bin_polygon (const octave_pq_connection_rep &conn,
 
   if (err || (nel = m.numel ()) % 2)
     {
-      c_verror ("can not convert octave_value to polygon representation");
+      _p_error ("can not convert octave_value to polygon representation");
       return 1;
     }
 
@@ -1520,7 +1520,7 @@ int from_octave_bin_path (const octave_pq_connection_rep &conn,
   SET_ERR (tp = ov.scalar_map_value (), err);
   if (err || ! tp.isfield ("closed") || ! tp.isfield ("path"))
     {
-      c_verror ("can not convert octave_value to path representation");
+      _p_error ("can not convert octave_value to path representation");
       return 1;
     }
 
@@ -1537,7 +1537,7 @@ int from_octave_bin_path (const octave_pq_connection_rep &conn,
 
   if (err || (nel = m.numel ()) % 2)
     {
-      c_verror ("can not convert octave_value to path representation");
+      _p_error ("can not convert octave_value to path representation");
       return 1;
     }
 
@@ -1590,7 +1590,7 @@ oct_pq_conv_t conv_path = {0,
 int to_octave_str_unknown (const octave_pq_connection_rep &conn,
                            const char *c, octave_value &ov, int nb)
 {
-  c_verror ("can not convert postgresql type 'unknown'");
+  _p_error ("can not convert postgresql type 'unknown'");
 
   return 1;
 }
@@ -1598,7 +1598,7 @@ int to_octave_str_unknown (const octave_pq_connection_rep &conn,
 int to_octave_bin_unknown (const octave_pq_connection_rep &conn,
                            const char *c, octave_value &ov, int nb)
 {
-  c_verror ("can not convert postgresql type 'unknown'");
+  _p_error ("can not convert postgresql type 'unknown'");
 
   return 1;
 }
@@ -1606,7 +1606,7 @@ int to_octave_bin_unknown (const octave_pq_connection_rep &conn,
 int from_octave_str_unknown (const octave_pq_connection_rep &conn,
                              const octave_value &ov, oct_pq_dynvec_t &val)
 {
-  c_verror ("can not convert postgresql type 'unknown'");
+  _p_error ("can not convert postgresql type 'unknown'");
 
   return 1;
 }
@@ -1614,7 +1614,7 @@ int from_octave_str_unknown (const octave_pq_connection_rep &conn,
 int from_octave_bin_unknown (const octave_pq_connection_rep &conn,
                              const octave_value &ov, oct_pq_dynvec_t &val)
 {
-  c_verror ("can not convert postgresql type 'unknown'");
+  _p_error ("can not convert postgresql type 'unknown'");
 
   return 1;
 }
@@ -1656,7 +1656,7 @@ int to_octave_bin_cidr_inet (const char *c, octave_value &ov, bool &cidr)
 
       if (nb > 4)
         {
-          c_verror ("internal error: received too many bytes for AF_INET type");
+          _p_error ("internal error: received too many bytes for AF_INET type");
 
           return 1;
         }
@@ -1680,7 +1680,7 @@ int to_octave_bin_cidr_inet (const char *c, octave_value &ov, bool &cidr)
 
       if (nb > 16)
         {
-          c_verror ("internal error: received too many bytes for AF_INET6 type");
+          _p_error ("internal error: received too many bytes for AF_INET6 type");
 
           return 1;
         }
@@ -1721,7 +1721,7 @@ int from_octave_bin_cidr_inet (const octave_value &ov, oct_pq_dynvec_t &val,
 
       if (err)
         {
-          c_verror ("can not convert octave_value to network type representation");
+          _p_error ("can not convert octave_value to network type representation");
           return 1;
         }
 
@@ -1745,7 +1745,7 @@ int from_octave_bin_cidr_inet (const octave_value &ov, oct_pq_dynvec_t &val,
 
       if (err)
         {
-          c_verror ("can not convert octave_value to network type representation");
+          _p_error ("can not convert octave_value to network type representation");
           return 1;
         }
 
@@ -1765,7 +1765,7 @@ int from_octave_bin_cidr_inet (const octave_value &ov, oct_pq_dynvec_t &val,
     }
   else
     {
-      c_verror ("invalid network type representation");
+      _p_error ("invalid network type representation");
       return 1;
     }
 
@@ -1792,7 +1792,7 @@ int to_octave_bin_cidr (const octave_pq_connection_rep &conn,
 
   if (! cidr)
     {
-      c_verror ("internal error: unexpected flag in cidr type");
+      _p_error ("internal error: unexpected flag in cidr type");
 
       return 1;
     }
@@ -1845,7 +1845,7 @@ int to_octave_bin_inet (const octave_pq_connection_rep &conn,
 
   if (cidr)
     {
-      c_verror ("internal error: unexpected flag in inet type");
+      _p_error ("internal error: unexpected flag in inet type");
 
       return 1;
     }
@@ -1915,13 +1915,13 @@ int from_octave_bin_macaddr (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to macaddr representation");
+      _p_error ("can not convert octave_value to macaddr representation");
       return 1;
     }
 
   if (a.numel () != 6)
     {
-      c_verror ("macaddr representation must have 6 elements");
+      _p_error ("macaddr representation must have 6 elements");
       return 1;
     }
 
@@ -1993,7 +1993,7 @@ int from_octave_bin_bit (const octave_pq_connection_rep &conn,
   SET_ERR (tp = ov.scalar_map_value (), err);
   if (err || ! tp.isfield ("bitlen") || ! tp.isfield ("bits"))
     {
-      c_verror ("can not convert octave_value to bitstring representation");
+      _p_error ("can not convert octave_value to bitstring representation");
       return 1;
     }
 
@@ -2008,7 +2008,7 @@ int from_octave_bin_bit (const octave_pq_connection_rep &conn,
 
   if (err || nbits < 0)
     {
-      c_verror ("can not convert octave_value to bitstring representation");
+      _p_error ("can not convert octave_value to bitstring representation");
       return 1;
     }
 
@@ -2016,7 +2016,7 @@ int from_octave_bin_bit (const octave_pq_connection_rep &conn,
 
   if (a.numel () != nbytes)
     {
-      c_verror ("wrong number of elements in bitstring representation");
+      _p_error ("wrong number of elements in bitstring representation");
       return 1;
     }
 
@@ -2098,13 +2098,13 @@ int from_octave_bin_uuid (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to uuid representation");
+      _p_error ("can not convert octave_value to uuid representation");
       return 1;
     }
 
   if (b.numel () != 16)
     {
-      c_verror ("uuid representation must have 16 elements");
+      _p_error ("uuid representation must have 16 elements");
       return 1;
     }
 
@@ -2165,7 +2165,7 @@ int from_octave_bin_xml (const octave_pq_connection_rep &conn,
 
   if (err)
     {
-      c_verror ("can not convert octave_value to string");
+      _p_error ("can not convert octave_value to string");
       return 1;
     }
 
@@ -2253,7 +2253,7 @@ int to_octave_bin_record (const octave_pq_connection_rep &conn,
 
             default:
               // should not get here
-              c_verror ("'record' converter: internal error, undefined type identifier");
+              _p_error ("'record' converter: internal error, undefined type identifier");
               return 1;
             }
 
@@ -2277,7 +2277,7 @@ int from_octave_str_record (const octave_pq_connection_rep &conn,
 int from_octave_bin_record (const octave_pq_connection_rep &conn,
                             const octave_value &ov, oct_pq_dynvec_t &val)
 {
-  c_verror ("Type 'record' can't be sent to postgresql.");
+  _p_error ("Type 'record' can't be sent to postgresql.");
 
   return 1;
 }
