@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2012-2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2012-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #define ERROR_RETURN_NO_PG_TYPE                                         \
  {                                                                      \
-   c_verror ("could not determine postgresql type for Octave parameter"); \
+   _p_error ("could not determine postgresql type for Octave parameter"); \
    return NULL;                                                         \
  }
 
@@ -57,7 +57,7 @@ oct_pq_conv_t *pgtype_from_spec (const octave_pq_connection_rep &conn,
   if ((iter = conn.name_conv_map.find (name.c_str ())) ==
       conn.name_conv_map.end ())
     {
-      c_verror ("no converter found for type %s",
+      _p_error ("no converter found for type %s",
                 name.c_str ());
       return NULL;
     }
@@ -69,7 +69,7 @@ oct_pq_conv_t *pgtype_from_spec (const octave_pq_connection_rep &conn,
 
       if (oct_type == array && ! conv->aoid)
         {
-          c_verror ("%s: internal error, type %s, specified as array, has no array type in system catalog", name.c_str ());
+          _p_error ("%s: internal error, type %s, specified as array, has no array type in system catalog", name.c_str ());
           return NULL;
         }
 
@@ -97,7 +97,7 @@ oct_pq_conv_t *pgtype_from_spec (const octave_pq_connection_rep &conn, Oid oid,
   
   if ((iter = conn.conv_map.find (oid)) == conn.conv_map.end ())
     {
-      c_verror ("no converter found for element oid %u", oid);
+      _p_error ("no converter found for element oid %u", oid);
       return NULL;
     }
   conv = iter->second.get_copy ();
@@ -193,9 +193,9 @@ oct_pq_conv_t *pgtype_from_octtype (const octave_pq_connection_rep &conn,
       return conn.name_conv_map.find ("text")->second.get_copy ();
     }
 
-  // is_real_type() is true for strings, so is_numeric_type() would
+  // isreal() is true for strings, so isnumeric() would
   // still be needed if strings were not recognized above
-  if (param.is_real_type ())
+  if (param.OV_ISREAL ())
     {
       switch (param.numel ())
         {
@@ -282,13 +282,13 @@ int from_octave_bin_array (const octave_pq_connection_rep &conn,
   SET_ERR (m= oct_arr.scalar_map_value (), err);
   if (err)
     {
-      c_verror ("Postgresql array parameter no Octave structure");
+      _p_error ("Postgresql array parameter no Octave structure");
       return 1;
     }
 
   if (! m.isfield ("ndims") || ! m.isfield ("data"))
     {
-      c_verror ("field 'ndims' or 'data' missing in parameter for Postgresql array");
+      _p_error ("field 'ndims' or 'data' missing in parameter for Postgresql array");
       return 1;
     }
 
@@ -302,7 +302,7 @@ int from_octave_bin_array (const octave_pq_connection_rep &conn,
     }
   if (err || nd_pq < 0)
     {
-      c_verror ("'ndims' and 'data' could not be converted to non-negative integer and cell-array in parameter for Postgresql array");
+      _p_error ("'ndims' and 'data' could not be converted to non-negative integer and cell-array in parameter for Postgresql array");
       return 1;
     }
 
@@ -314,7 +314,7 @@ int from_octave_bin_array (const octave_pq_connection_rep &conn,
       SET_ERR (lb = m.contents ("lbounds").row_vector_value (), err);
       if (err)
         {
-          c_verror ("could not convert given enumeration bases for array to row vector");
+          _p_error ("could not convert given enumeration bases for array to row vector");
           return 1;
         }
     }
@@ -331,16 +331,16 @@ int from_octave_bin_array (const octave_pq_connection_rep &conn,
   // check dimensions
   if (nd_oct > nd_pq)
     {
-      c_verror ("given representation of postgresql array has more dimensions than specified");
+      _p_error ("given representation of postgresql array has more dimensions than specified");
       return 1;
     }
 
   // check lbounds
-  if (nd_pq > 0 && lb.is_empty ())
+  if (nd_pq > 0 && lb.OV_ISEMPTY ())
     lb.resize (nd_pq, 1); // fill with 1
   else if (lb.numel () != nd_pq)
     {
-      c_verror ("number of specified enumeration bases for array does not match specified number of dimensions");
+      _p_error ("number of specified enumeration bases for array does not match specified number of dimensions");
       return 1;
     }
 
@@ -399,7 +399,7 @@ int from_octave_bin_composite (const octave_pq_connection_rep &conn,
   SET_ERR (rec = oct_comp.cell_value (), err);
   if (err)
     {
-      c_verror ("Octaves representation of a composite type could not be converted to cell-array");
+      _p_error ("Octaves representation of a composite type could not be converted to cell-array");
       return 1;
     }
 
@@ -407,7 +407,7 @@ int from_octave_bin_composite (const octave_pq_connection_rep &conn,
 
   if (size_t (nl) != conv->el_oids.size ())
     {
-      c_verror ("Octaves representation of a composite type has incorrect number of elements (%i, should have %i)",
+      _p_error ("Octaves representation of a composite type has incorrect number of elements (%i, should have %i)",
              nl, conv->el_oids.size ());
 
       return 1;
@@ -456,7 +456,7 @@ int from_octave_bin_composite (const octave_pq_connection_rep &conn,
 
             default:
               // should not get here
-              c_verror ("internal error, undefined type identifier");
+              _p_error ("internal error, undefined type identifier");
               return 1;
             }
 
@@ -472,7 +472,7 @@ int from_octave_str_array (const octave_pq_connection_rep &conn,
                            oct_pq_dynvec_t &val, octave_value &type)
 {
   // not implemented
-  c_verror ("not implemented");
+  _p_error ("not implemented");
   return 1;
 
   return 0;
@@ -484,7 +484,7 @@ int from_octave_str_composite (const octave_pq_connection_rep &conn,
                                octave_value &type)
 {
   // not implemented
-  c_verror ("not implemented");
+  _p_error ("not implemented");
   return 1;
 
   return 0;
@@ -510,7 +510,7 @@ int to_octave_bin_array (const octave_pq_connection_rep &conn,
   // check element OID
   if (oid != conv->oid)
     {
-      c_verror ("element oid %i sent by server does not match element oid %i expected for array with oid %i",
+      _p_error ("element oid %i sent by server does not match element oid %i expected for array with oid %i",
              oid, conv->oid, conv->aoid);
       return 1;
     }
@@ -627,7 +627,7 @@ int to_octave_bin_composite (const octave_pq_connection_rep &conn,
 
             default:
               // should not get here
-              c_verror ("internal error, undefined type identifier");
+              _p_error ("internal error, undefined type identifier");
               return 1;
             }
 
@@ -648,7 +648,7 @@ int to_octave_str_array (const octave_pq_connection_rep &conn,
                          oct_pq_conv_t *conv)
 {
   // not implemented
-  c_verror ("not implemented");
+  _p_error ("not implemented");
   return 1;
 
   return 0;
@@ -659,7 +659,7 @@ int to_octave_str_composite (const octave_pq_connection_rep &conn,
                              oct_pq_conv_t *conv)
 {
   // not implemented
-  c_verror ("not implemented");
+  _p_error ("not implemented");
   return 1;
 
   return 0;
