@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2012-2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2012-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ octave_pq_connection_rep::octave_pq_connection_rep (std::string &arg)
     {
       if (conn)
         {
-          c_verror ("%s", PQerrorMessage (conn));
+          _p_error ("%s", PQerrorMessage (conn));
 
           PGconn *t_conn = conn;
 
@@ -69,7 +69,7 @@ octave_pq_connection_rep::octave_pq_connection_rep (std::string &arg)
           END_INTERRUPT_IMMEDIATELY_IN_FOREIGN_CODE;
         }
 
-      c_verror ("PQ connection attempt failed");
+      _p_error ("PQ connection attempt failed");
     }
   else
     {
@@ -95,7 +95,7 @@ octave_pq_connection_rep::octave_pq_connection_rep (std::string &arg)
           PQfinish (t_conn);
           END_INTERRUPT_IMMEDIATELY_IN_FOREIGN_CODE;
 
-          c_verror ("could not read types");
+          _p_error ("could not read types");
         }
       else
         {
@@ -193,7 +193,7 @@ int octave_pq_connection_rep::octave_pq_get_postgres_oid (void)
   command c (*this, cmd, p, pt, rt, caller);
   if (! c.good ())
     {
-      c_verror ("could not read pg_roles");
+      _p_error ("could not read pg_roles");
       return 1;
     }
 
@@ -227,7 +227,7 @@ int octave_pq_connection_rep::octave_pq_fill_base_types (void)
   command c (*this, cmd, p, pt, rt, caller);
   if (! c.good ())
     {
-      c_verror ("octave_pq_fill_base_types: could not read pg_type");
+      _p_error ("octave_pq_fill_base_types: could not read pg_type");
       return 1;
     }
 
@@ -241,7 +241,7 @@ int octave_pq_connection_rep::octave_pq_fill_base_types (void)
            err);
   if (err)
     {
-      c_verror
+      _p_error
         ("octave_pq_fill_base_types: could not convert result data to cell");
       return 1;
     }
@@ -259,7 +259,7 @@ int octave_pq_connection_rep::octave_pq_fill_base_types (void)
     }
   if (err)
     {
-      c_verror ("octave_pq_fill_base_types: could not read returned result");
+      _p_error ("octave_pq_fill_base_types: could not read returned result");
       return 1;
     }
 
@@ -269,7 +269,7 @@ int octave_pq_connection_rep::octave_pq_fill_base_types (void)
       if ((bt_it = bt_map.find (conv_ptrs[i]->name.c_str () + pq_bpl)) ==
           bt_map.end ())
         {
-          c_verror ("octave_pq_fill_base_types: type %s not found in pg_type",
+          _p_error ("octave_pq_fill_base_types: type %s not found in pg_type",
                     conv_ptrs[i]->name.c_str () + pq_bpl);
           return 1;
         }
@@ -291,7 +291,7 @@ int octave_pq_connection_rep::octave_pq_fill_base_types (void)
     }
   if (err)
     {
-      c_verror ("octave_pq_fill_base_types: could not read returned result");
+      _p_error ("octave_pq_fill_base_types: could not read returned result");
       return 1;
     }
 
@@ -308,7 +308,7 @@ int octave_pq_connection_rep::octave_pq_get_composite_types (void)
   command c (*this, cmd, p, pt, rt, caller);
   if (! c.good ())
     {
-      c_verror ("octave_pq_get_composite_types: could not read pg_type");
+      _p_error ("octave_pq_get_composite_types: could not read pg_type");
       return 1;
     }
 
@@ -322,7 +322,7 @@ int octave_pq_connection_rep::octave_pq_get_composite_types (void)
            err)
   if (err)
     {
-      c_verror ("octave_pq_get_composite_types: could not convert result data to cell");
+      _p_error ("octave_pq_get_composite_types: could not convert result data to cell");
       return 1;
     }
 
@@ -364,13 +364,13 @@ int octave_pq_connection_rep::octave_pq_get_composite_types (void)
         }
       if (err)
         {
-          c_verror ("octave_pq_get_composite_types: could not read returned result");
+          _p_error ("octave_pq_get_composite_types: could not read returned result");
           return 1;
         }
       octave_idx_type nel = r_el_oids.numel ();
       if (nel != r_el_pos.numel ())
         {
-          c_verror ("octave_pq_get_composite_types: internal error, inconsistent content of pg_attribute?");
+          _p_error ("octave_pq_get_composite_types: internal error, inconsistent content of pg_attribute?");
 
           return 1;
         }
@@ -387,7 +387,7 @@ int octave_pq_connection_rep::octave_pq_get_composite_types (void)
             {
               if (pos >= nel)
                 {
-                  c_verror ("octave_pq_get_composite_types: internal error (?system catalog erroneous?): column position %i greater than ncols %i for type %s, namespace %s",
+                  _p_error ("octave_pq_get_composite_types: internal error (?system catalog erroneous?): column position %i greater than ncols %i for type %s, namespace %s",
                          pos, nel, name.c_str (), nspace.c_str ());
                   return 1;
                 }
@@ -398,7 +398,7 @@ int octave_pq_connection_rep::octave_pq_get_composite_types (void)
             }
           if (err)
             {
-              c_verror ("octave_pq_get_composite_types: could not fill in element oids.");
+              _p_error ("octave_pq_get_composite_types: could not fill in element oids.");
 
               return 1;
             }
@@ -425,7 +425,7 @@ int octave_pq_connection_rep::octave_pq_get_composite_types (void)
         *&by_name = name_conv_map[t_conv->name.c_str ()];
       if (by_oid || by_name)
         {
-          c_verror ("octave_pq_get_composite_types: internal error, key already in typemap (by_oid: %u/%li, by name: %s/%li)",
+          _p_error ("octave_pq_get_composite_types: internal error, key already in typemap (by_oid: %u/%li, by name: %s/%li)",
                  oid, by_oid, t_conv->name.c_str (), by_name);
           if (! by_oid) conv_map.erase (oid);
           if (! by_name) name_conv_map.erase (t_conv->name.c_str ());
@@ -456,7 +456,7 @@ int octave_pq_connection_rep::octave_pq_get_composite_types (void)
           oct_pq_conv_t *&by_aoid = conv_map[aoid];
           if (by_aoid)
             {
-              c_verror ("octave_pq_get_composite_types: internal error, aoid key %u already in typemap", aoid);
+              _p_error ("octave_pq_get_composite_types: internal error, aoid key %u already in typemap", aoid);
               conv_map.erase (oid);
               name_conv_map.erase (t_conv->name.c_str ());
               delete t_conv;
@@ -486,7 +486,7 @@ int octave_pq_connection_rep::octave_pq_get_enum_types (void)
   command c (*this, cmd, p, pt, rt, caller);
   if (! c.good ())
     {
-      c_verror ("octave_pq_get_enum_types: could not read pg_type");
+      _p_error ("octave_pq_get_enum_types: could not read pg_type");
       return 1;
     }
  
@@ -500,7 +500,7 @@ int octave_pq_connection_rep::octave_pq_get_enum_types (void)
            err);
   if (err)
     {
-      c_verror ("octave_pq_get_enum_types: could not convert result data to cell");
+      _p_error ("octave_pq_get_enum_types: could not convert result data to cell");
       return 1;
     }
 
@@ -530,7 +530,7 @@ int octave_pq_connection_rep::octave_pq_get_enum_types (void)
         }
       if (err)
         {
-          c_verror ("octave_pq_get_enum_types: could not read returned result");
+          _p_error ("octave_pq_get_enum_types: could not read returned result");
           return 1;
         }
 
@@ -556,7 +556,7 @@ int octave_pq_connection_rep::octave_pq_get_enum_types (void)
         *&by_name = name_conv_map[t_conv->name.c_str ()];
       if (by_oid || by_aoid || by_name)
         {
-          c_verror ("octave_pq_get_enum_types: internal error, key already in typemap");
+          _p_error ("octave_pq_get_enum_types: internal error, key already in typemap");
           if (! by_oid) conv_map.erase (oid);
           if (! by_aoid) conv_map.erase (aoid);
           if (! by_name) name_conv_map.erase (t_conv->name.c_str ());
@@ -605,7 +605,7 @@ int octave_pq_connection_rep::octave_pq_refresh_types (void)
           END_INTERRUPT_IMMEDIATELY_IN_FOREIGN_CODE;
         }
 
-      c_verror ("octave_pq_refresh_types: could not read types");
+      _p_error ("octave_pq_refresh_types: could not read types");
       return 1;
     }
   else
