@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2013-2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2013-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -129,7 +129,7 @@ pipe_to_lo::pipe_to_lo (octave_pq_connection_rep &a_oct_pq_conn,
   if (nb) return;
 
   if (pclose (fp) == -1)
-    c_verror ("error closing pipe");
+    _p_error ("error closing pipe");
 
   fp = NULL;
 
@@ -146,7 +146,7 @@ pipe_to_lo::~pipe_to_lo (void)
   if (lod != -1)
     {
       if (lo_close (conn, lod))
-        c_verror ("%s", PQerrorMessage (conn));
+        _p_error ("%s", PQerrorMessage (conn));
 
       lod = -1;
     }
@@ -154,7 +154,7 @@ pipe_to_lo::~pipe_to_lo (void)
   if (oid && ! oid_valid)
     {
       if (lo_unlink (conn, oid) == -1)
-        c_verror ("error unlinking new large object with oid %i", oid);
+        _p_error ("error unlinking new large object with oid %i", oid);
     }
   else
     oid = 0;
@@ -162,7 +162,7 @@ pipe_to_lo::~pipe_to_lo (void)
   if (fp)
     {
       if (pclose (fp) == -1)
-        c_verror ("error closing pipe");
+        _p_error ("error closing pipe");
 
       fp = NULL;
     }
@@ -180,7 +180,7 @@ pipe_to_lo::~pipe_to_lo (void)
         c.process_single_result ();
 
       if (! c.good ())
-        c_verror ("%s: could not commit", caller.c_str ());
+        _p_error ("%s: could not commit", caller.c_str ());
     }
 }
 
@@ -270,7 +270,7 @@ lo_to_pipe::lo_to_pipe (octave_pq_connection_rep &a_oct_pq_conn, Oid aoid,
   if (pnb) return;
 
   if (pclose (fp) == -1)
-    c_verror ("error closing pipe");
+    _p_error ("error closing pipe");
 
   fp = NULL;
 
@@ -287,7 +287,7 @@ lo_to_pipe::~lo_to_pipe (void)
   if (lod != -1)
     {
       if (lo_close (conn, lod))
-        c_verror ("%s", PQerrorMessage (conn));
+        _p_error ("%s", PQerrorMessage (conn));
 
       lod = -1;
     }
@@ -295,7 +295,7 @@ lo_to_pipe::~lo_to_pipe (void)
   if (fp)
     {
       if (pclose (fp) == -1)
-        c_verror ("error closing pipe");
+        _p_error ("error closing pipe");
 
       fp = NULL;
     }
@@ -313,7 +313,7 @@ lo_to_pipe::~lo_to_pipe (void)
         c.process_single_result ();
 
       if (! c.good ())
-        c_verror ("%s: could not commit", caller.c_str ());
+        _p_error ("%s: could not commit", caller.c_str ());
     }
 }
 
@@ -453,11 +453,11 @@ Imports the file in @var{path} on the client side as a large object into the dat
     }
 
   if (import_error)
-    c_verror ("%s: large object import failed: %s",
+    _p_error ("%s: large object import failed: %s",
               fname.c_str (), msg.c_str ());
 
   if (commit_error)
-    c_verror ("%s: could not commit transaction", fname.c_str ());
+    _p_error ("%s: could not commit transaction", fname.c_str ());
 
   if (import_error || commit_error)
     {
@@ -603,11 +603,11 @@ Exports the large object of Oid @var{oid} in the database associated with @var{c
     }
 
   if (export_error)
-    c_verror ("%s: large object export failed: %s",
+    _p_error ("%s: large object export failed: %s",
               fname.c_str (), msg.c_str ());
 
   if (commit_error)
-    c_verror ("%s: could not commit transaction", fname.c_str ());
+    _p_error ("%s: could not commit transaction", fname.c_str ());
 
   if (export_error || commit_error)
     error ("%s failed", fname.c_str ());
@@ -717,11 +717,11 @@ Removes the large object of Oid @var{oid} from the database associated with @var
     }
 
   if (unlink_error)
-    c_verror ("%s: large object unlink failed: %s",
+    _p_error ("%s: large object unlink failed: %s",
               fname.c_str (), msg.c_str ());
 
   if (commit_error)
-    c_verror ("%s: could not commit transaction", fname.c_str ());
+    _p_error ("%s: could not commit transaction", fname.c_str ());
 
   if (unlink_error || commit_error)
     error ("%s failed", fname.c_str ());      
