@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2016 Olaf Till <i7tiol@t-online.de>
+Copyright (C) 2016-2018 Olaf Till <i7tiol@t-online.de>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #include <octave/ls-mat4.h>
 
+#include "config.h"
+
 DEFUN_DLD (var2bytea, args, nout,
            "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {} var2bytea (@var{value}, @dots{})\n\
@@ -68,10 +70,10 @@ can be used.\n\
         to reduce storage size
       */
 
-      os << (oct_mach_info::words_big_endian () ? "1B" : "1L");
+      os << (OCTAVE__MACH_INFO::words_big_endian () ? "1B" : "1L");
 
-      oct_mach_info::float_format flt_fmt =
-        oct_mach_info::native_float_format ();
+      OCTAVE__MACH_INFO::float_format flt_fmt =
+        OCTAVE__MACH_INFO::native_float_format ();
 
       char tmp = static_cast<char> (float_format_to_mopt_digit (flt_fmt));
 
